"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setSessionId = exports.getSessionId = exports.createSessionId = void 0;
var _cookie = require("./cookie");
var _nullable = require("./nullable");
var _uuid = require("./uuid");
const SESSION_LOCAL_STORAGE_KEY = 'builderSessionId';
const getSessionId = async ({
  canTrack
}) => {
  if (!canTrack) {
    return undefined;
  }
  const sessionId = await (0, _cookie.getCookie)({
    name: SESSION_LOCAL_STORAGE_KEY,
    canTrack
  });
  if ((0, _nullable.checkIsDefined)(sessionId)) {
    return sessionId;
  } else {
    const newSessionId = createSessionId();
    setSessionId({
      id: newSessionId,
      canTrack
    });
    return newSessionId;
  }
};
exports.getSessionId = getSessionId;
const createSessionId = () => (0, _uuid.uuid)();
exports.createSessionId = createSessionId;
const setSessionId = ({
  id,
  canTrack
}) => (0, _cookie.setCookie)({
  name: SESSION_LOCAL_STORAGE_KEY,
  value: id,
  canTrack
});
exports.setSessionId = setSessionId;
//# sourceMappingURL=sessionId.js.map