import { evaluate } from "../../functions/evaluate/index";
import { extractTextStyles } from "../../functions/extract-text-styles";
import { getStyle } from "../../functions/get-style";
const checkIsComponentRestricted = (component, model) => {
  if (!component) return true;
  if (!model) return false;
  return component.models && component.models.length > 0 && !component.models.includes(model);
};
export const getComponent = ({
  block,
  registeredComponents,
  model
}) => {
  var _block$component;
  const componentName = (_block$component = block.component) === null || _block$component === void 0 ? void 0 : _block$component.name;
  if (!componentName) {
    return null;
  }
  const ref = registeredComponents[componentName];
  if (!ref || checkIsComponentRestricted(ref, model)) {
    // TODO: Public doc page with more info about this message
    console.warn(`
      Could not find a registered component named "${componentName}". 
      If you registered it, is the file that registered it imported by the file that needs to render it?`);
    return undefined;
  } else {
    return ref;
  }
};
export const getRepeatItemData = ({
  block,
  context
}) => {
  /**
   * we don't use `state.processedBlock` here because the processing done within its logic includes evaluating the block's bindings,
   * which will not work if there is a repeat.
   */
  const {
    repeat,
    ...blockWithoutRepeat
  } = block;
  if (!(repeat !== null && repeat !== void 0 && repeat.collection)) {
    return undefined;
  }
  const itemsArray = evaluate({
    code: repeat.collection,
    localState: context.localState,
    rootState: context.rootState,
    rootSetState: context.rootSetState,
    context: context.context
  });
  if (!Array.isArray(itemsArray)) {
    return undefined;
  }
  const collectionName = repeat.collection.split('.').pop();
  const itemNameToUse = repeat.itemName || (collectionName ? collectionName + 'Item' : 'item');
  const repeatArray = itemsArray.map((item, index) => ({
    context: {
      ...context,
      localState: {
        ...context.localState,
        $index: index,
        $item: item,
        [itemNameToUse]: item,
        [`$${itemNameToUse}Index`]: index
      }
    },
    block: blockWithoutRepeat
  }));
  return repeatArray;
};
export const getInheritedStyles = ({
  block,
  context
}) => {
  const style = getStyle({
    block,
    context
  });
  if (!style) {
    return {};
  }
  return extractTextStyles(style);
};
export const provideLinkComponent = (block, linkComponent) => {
  var _block$shouldReceiveB;
  if (block !== null && block !== void 0 && (_block$shouldReceiveB = block.shouldReceiveBuilderProps) !== null && _block$shouldReceiveB !== void 0 && _block$shouldReceiveB.builderLinkComponent) return {
    builderLinkComponent: linkComponent
  };
  return {};
};
export const provideRegisteredComponents = (block, registeredComponents, model) => {
  var _block$shouldReceiveB2;
  if (block !== null && block !== void 0 && (_block$shouldReceiveB2 = block.shouldReceiveBuilderProps) !== null && _block$shouldReceiveB2 !== void 0 && _block$shouldReceiveB2.builderComponents) {
    const filteredRegisteredComponents = Object.fromEntries(Object.entries(registeredComponents).filter(([_, component]) => {
      return !checkIsComponentRestricted(component, model);
    }));
    return {
      builderComponents: filteredRegisteredComponents
    };
  }
  return {};
};
export const provideBuilderBlock = (block, builderBlock) => {
  var _block$shouldReceiveB3;
  if (block !== null && block !== void 0 && (_block$shouldReceiveB3 = block.shouldReceiveBuilderProps) !== null && _block$shouldReceiveB3 !== void 0 && _block$shouldReceiveB3.builderBlock) return {
    builderBlock
  };
  return {};
};
export const provideBuilderContext = (block, context) => {
  var _block$shouldReceiveB4;
  if (block !== null && block !== void 0 && (_block$shouldReceiveB4 = block.shouldReceiveBuilderProps) !== null && _block$shouldReceiveB4 !== void 0 && _block$shouldReceiveB4.builderContext) return {
    builderContext: context
  };
  return {};
};
export const generateKey = index => {
  //This does not handle the case in Qwik
  return index.toString();
};
//# sourceMappingURL=block.helpers.js.map