import { traverse } from "./traverse";
function isLocalizedField(value) {
  return value && typeof value === 'object' && value['@type'] === '@builder.io/core:LocalizedValue';
}
function containsLocalizedValues(data) {
  if (!data || !Object.getOwnPropertyNames(data).length) {
    return false;
  }
  let hasLocalizedValues = false;
  traverse(data, value => {
    if (isLocalizedField(value)) {
      hasLocalizedValues = true;
      return;
    }
  });
  return hasLocalizedValues;
}
function extractLocalizedValues(data, locale) {
  if (!data || !Object.getOwnPropertyNames(data).length) {
    return {};
  }
  traverse(data, (value, update) => {
    if (isLocalizedField(value)) {
      update(value[locale] ?? undefined);
    }
  });
  return data;
}
export function resolveLocalizedValues(block, locale) {
  var _block$component, _block$component2;
  if ((_block$component = block.component) !== null && _block$component !== void 0 && _block$component.options && containsLocalizedValues((_block$component2 = block.component) === null || _block$component2 === void 0 ? void 0 : _block$component2.options)) {
    if (!locale) {
      console.warn('[Builder.io] In order to use localized fields in Builder, you must pass a locale prop to the BuilderComponent or to options object while fetching the content to resolve localized fields. Learn more: https://www.builder.io/c/docs/localization-inline#targeting-and-inline-localization');
    }
    block.component.options = extractLocalizedValues(block.component.options, locale ?? 'Default');
  }
  return block;
}
//# sourceMappingURL=extract-localized-values.js.map