"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchBuilderProps = void 0;
var _index = require("./get-builder-search-params/index");
var _index2 = require("./get-content/index");
/**
 * Given an `apiKey` and `url` (or `path` + `searchParams`), provides all props that `Content` needs to render Builder Content.
 *
 * @example
 * ```jsx
 * const builderProps = await fetchBuilderProps({
 *    apiKey: 'API_KEY',
 *    // provide `url`
 *    url: yourPageUrl,
 *    // OR provide `path` + `searchParams`
 *    path: yourPath,
 *    searchParams: yourSearchParams,
 * });
 *
 * return <Content {...builderProps} />;
 * ```
 */
const fetchBuilderProps = async _args => {
  var _args$url, _args$userAttributes, _args$url2;
  const urlPath = _args.path || ((_args$url = _args.url) === null || _args$url === void 0 ? void 0 : _args$url.pathname) || ((_args$userAttributes = _args.userAttributes) === null || _args$userAttributes === void 0 ? void 0 : _args$userAttributes.urlPath);
  const getContentArgs = {
    ..._args,
    apiKey: _args.apiKey,
    model: _args.model || 'page',
    userAttributes: {
      ..._args.userAttributes,
      ...(urlPath ? {
        urlPath
      } : {})
    },
    options: (0, _index.getBuilderSearchParams)(_args.searchParams || ((_args$url2 = _args.url) === null || _args$url2 === void 0 ? void 0 : _args$url2.searchParams) || _args.options)
  };
  return {
    apiKey: getContentArgs.apiKey,
    model: getContentArgs.model,
    content: await (0, _index2.fetchOneEntry)(getContentArgs)
  };
};
exports.fetchBuilderProps = fetchBuilderProps;
//# sourceMappingURL=fetch-builder-props.js.map