"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBuilderSearchParamsFromWindow = exports.getBuilderSearchParams = void 0;
var _search = require("../../helpers/search/search");
var _isBrowser = require("../is-browser");
const BUILDER_SEARCHPARAMS_PREFIX = 'builder.';
const BUILDER_OPTIONS_PREFIX = 'options.';

/**
 * Receives a `URLSearchParams` object or a regular query object, and returns the subset of query params that are
 * relevant to the Builder SDK.
 *
 * @returns
 */
const getBuilderSearchParams = _options => {
  if (!_options) {
    return {};
  }
  const options = (0, _search.normalizeSearchParams)(_options);
  const newOptions = {};
  Object.keys(options).forEach(key => {
    if (key.startsWith(BUILDER_SEARCHPARAMS_PREFIX)) {
      const trimmedKey = key.replace(BUILDER_SEARCHPARAMS_PREFIX, '').replace(BUILDER_OPTIONS_PREFIX, '');
      newOptions[trimmedKey] = options[key];
    }
  });
  return newOptions;
};
exports.getBuilderSearchParams = getBuilderSearchParams;
const getBuilderSearchParamsFromWindow = () => {
  if (!(0, _isBrowser.isBrowser)()) {
    return {};
  }
  const searchParams = new URLSearchParams(window.location.search);
  return getBuilderSearchParams(searchParams);
};
exports.getBuilderSearchParamsFromWindow = getBuilderSearchParamsFromWindow;
//# sourceMappingURL=index.js.map