"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUserAttributes = void 0;
var _target = require("../../constants/target");
var _isBrowser = require("../is-browser");
const getLocation = () => {
  if (_target.TARGET === 'reactNative') {
    return null;
  } else if ((0, _isBrowser.isBrowser)()) {
    const parsedLocation = new URL(location.href);

    // IE11 bug with parsed path being empty string
    // causes issues with our user targeting
    if (parsedLocation.pathname === '') {
      parsedLocation.pathname = '/';
    }
    return parsedLocation;
  } else {
    console.warn('Cannot get location for tracking in non-browser environment');
    return null;
  }
};
const getUserAgent = () => typeof navigator === 'object' && navigator.userAgent || '';
const getUserAttributes = () => {
  const userAgent = getUserAgent();
  const isMobile = {
    Android() {
      return userAgent.match(/Android/i);
    },
    BlackBerry() {
      return userAgent.match(/BlackBerry/i);
    },
    iOS() {
      return userAgent.match(/iPhone|iPod/i);
    },
    Opera() {
      return userAgent.match(/Opera Mini/i);
    },
    Windows() {
      return userAgent.match(/IEMobile/i) || userAgent.match(/WPDesktop/i);
    },
    any() {
      return isMobile.Android() || isMobile.BlackBerry() || isMobile.iOS() || isMobile.Opera() || isMobile.Windows() || _target.TARGET === 'reactNative';
    }
  };
  const isTablet = userAgent.match(/Tablet|iPad/i);
  const url = getLocation();
  return {
    urlPath: url === null || url === void 0 ? void 0 : url.pathname,
    host: (url === null || url === void 0 ? void 0 : url.host) || (url === null || url === void 0 ? void 0 : url.hostname),
    device: isTablet ? 'tablet' : isMobile.any() ? 'mobile' : 'desktop'
  };
};
exports.getUserAttributes = getUserAttributes;
//# sourceMappingURL=helpers.js.map