import * as React from "react";
import { View, Pressable } from "react-native";
import { useState } from "react";
import Blocks from "../../components/blocks/index";
function Accordion(props) {
  var _props$items;
  const [open, setOpen] = useState(() => []);
  function onlyOneAtATime() {
    return Boolean(props.grid || props.oneAtATime);
  }
  function accordionStyles() {
    const styles = {
      display: "flex",
      alignItems: "stretch",
      flexDirection: "column",
      ...(props.grid && {
        flexDirection: "row",
        alignItems: "flex-start",
        flexWrap: "wrap"
      })
    };
    return styles;
  }
  function accordionTitleStyles() {
    const shared = {
      display: "flex",
      flexDirection: "column"
    };
    const styles = shared;
    return Object.fromEntries(Object.entries(styles).filter(([_, value]) => value !== undefined));
  }
  function getAccordionTitleClassName(index) {
    return `builder-accordion-title builder-accordion-title-${open.includes(index) ? "open" : "closed"}`;
  }
  function getAccordionDetailClassName(index) {
    return `builder-accordion-detail builder-accordion-detail-${open.includes(index) ? "open" : "closed"}`;
  }
  function openGridItemOrder() {
    let itemOrder = null;
    const getOpenGridItemPosition = props.grid && open.length;
    if (getOpenGridItemPosition && document) {
      const openItemIndex = open[0];
      const openItem = document.querySelector(`.builder-accordion-title[data-index="${openItemIndex}"]`);
      let subjectItem = openItem;
      itemOrder = openItemIndex;
      if (subjectItem) {
        let prevItemRect = subjectItem.getBoundingClientRect();
        while (subjectItem = subjectItem && subjectItem.nextElementSibling) {
          if (subjectItem) {
            if (subjectItem.classList.contains("builder-accordion-detail")) {
              continue;
            }
            const subjectItemRect = subjectItem.getBoundingClientRect();
            if (subjectItemRect.left > prevItemRect.left) {
              const index = parseInt(subjectItem.getAttribute("data-index") || "", 10);
              if (!isNaN(index)) {
                prevItemRect = subjectItemRect;
                itemOrder = index;
              }
            } else {
              break;
            }
          }
        }
      }
    }
    if (typeof itemOrder === "number") {
      itemOrder = itemOrder + 1;
    }
    return itemOrder;
  }
  function accordionDetailStyles() {
    const styles = {
      ...{},
      ...(props.grid && {
        width: "100%"
      })
    };
    return Object.fromEntries(Object.entries(styles).filter(([_, value]) => value !== undefined));
  }
  function onClick(index) {
    if (open.includes(index)) {
      setOpen(onlyOneAtATime() ? [] : open.filter(item => item !== index));
    } else {
      setOpen(onlyOneAtATime() ? [index] : open.concat(index));
    }
  }
  return /*#__PURE__*/React.createElement(View, {
    style: accordionStyles()
  }, (_props$items = props.items) === null || _props$items === void 0 ? void 0 : _props$items.map((item, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, /*#__PURE__*/React.createElement(Pressable, {
    style: {
      ...accordionTitleStyles(),
      ...(props.grid && {
        width: props.gridRowWidth,
        ...{}
      })
    },
    "data-index": index,
    onPress: event => onClick(index)
  }, /*#__PURE__*/React.createElement(Blocks, {
    blocks: item.title,
    path: `items.${index}.title`,
    parent: props.builderBlock.id,
    context: props.builderContext,
    registeredComponents: props.builderComponents,
    linkComponent: props.builderLinkComponent
  })), open.includes(index) ? /*#__PURE__*/React.createElement(View, {
    style: accordionDetailStyles()
  }, /*#__PURE__*/React.createElement(Blocks, {
    blocks: item.detail,
    path: `items.${index}.detail`,
    parent: props.builderBlock.id,
    context: props.builderContext,
    registeredComponents: props.builderComponents,
    linkComponent: props.builderLinkComponent
  })) : null)));
}
export default Accordion;
//# sourceMappingURL=accordion.js.map