"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Text;
var _reactNativeRenderHtml = require("@builder.io/react-native-render-html");
var React = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _builder = _interopRequireDefault(require("../../context/builder.context"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * @typedef {{}} BuilderBlock
 */

/**
 * @typedef {{}} BuilderContext
 */

/**
 *
 * @param {string} string
 * @returns {string}
 */
function camelToKebabCase(string) {
  return string.replace(/([a-z0-9]|(?=[A-Z]))([A-Z])/g, '$1-$2').toLowerCase();
}

/**
 *
 * @param {object} object
 * @param {string[]} keys
 * @returns {object}
 */
function pick(object, keys) {
  return keys.reduce((obj, key) => {
    // eslint-disable-next-line no-prototype-builtins
    if (object && object.hasOwnProperty(key)) {
      obj[key] = object[key];
    }
    return obj;
  }, {});
}
const PICK_STYLES = ['textAlign'];

/**
 * @param {BuilderBlock} block
 * @returns
 */
function getBlockStyles(block) {
  var _block$responsiveStyl, _block$responsiveStyl2, _block$responsiveStyl3;
  // TODO: responsive CSS using react native viewport width hooks
  const styles = {
    ...((_block$responsiveStyl = block.responsiveStyles) === null || _block$responsiveStyl === void 0 ? void 0 : _block$responsiveStyl.large),
    ...block.styles
  };
  if ((_block$responsiveStyl2 = block.responsiveStyles) !== null && _block$responsiveStyl2 !== void 0 && _block$responsiveStyl2.medium) {
    Object.assign(styles, block.responsiveStyles.medium);
  }
  if ((_block$responsiveStyl3 = block.responsiveStyles) !== null && _block$responsiveStyl3 !== void 0 && _block$responsiveStyl3.small) {
    Object.assign(styles, block.responsiveStyles.small);
  }
  return styles;
}

/**
 *
 * @param {BuilderBlock} block
 * @param {any} inheritedStyles
 * @returns
 */
function getCss(block, inheritedStyles) {
  const styleObject = {
    ...inheritedStyles,
    ...pick(getBlockStyles(block), PICK_STYLES)
  };
  if (!styleObject) {
    return '';
  }
  let str = ``;
  for (const key in styleObject) {
    const value = styleObject[key];
    if (typeof value === 'string') {
      str += `${camelToKebabCase(key)}: ${value};`;
    }
  }
  return str;
}

/**
 *
 * @param {{ text: string; builderBlock: BuilderBlock, builderContext: BuilderContext}} props
 * @returns
 */
function Text(props) {
  var _props$text;
  const {
    width
  } = (0, _reactNative.useWindowDimensions)();
  const context = React.useContext(_builder.default);
  return /*#__PURE__*/React.createElement(_reactNativeRenderHtml.RenderHTML, {
    contentWidth: width,
    source: {
      html: `<div style="${getCss(props.builderBlock, context.inheritedStyles)}">${((_props$text = props.text) === null || _props$text === void 0 ? void 0 : _props$text.toString()) || ''}</div>`
    }
  });
}
//# sourceMappingURL=text.js.map