"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var React = _interopRequireWildcard(require("react"));
var _deviceSizes = require("../../../constants/device-sizes");
var _target = require("../../../constants/target");
var _camelToKebabCase = require("../../../functions/camel-to-kebab-case");
var _css = require("../../../helpers/css");
var _nullable = require("../../../helpers/nullable");
var _inlinedStyles = _interopRequireDefault(require("../../inlined-styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function BlockStyles(props) {
  function canShowBlock() {
    const processedBlock = props.block;
    // only render styles for blocks that are visible
    if ((0, _nullable.checkIsDefined)(processedBlock.hide)) {
      return !processedBlock.hide;
    }
    if ((0, _nullable.checkIsDefined)(processedBlock.show)) {
      return processedBlock.show;
    }
    return true;
  }
  function css() {
    var _content$meta, _content$meta2;
    const processedBlock = props.block;
    const styles = processedBlock.responsiveStyles;
    const content = props.context.content;
    const sizesWithUpdatedBreakpoints = (0, _deviceSizes.getSizesForBreakpoints)((content === null || content === void 0 || (_content$meta = content.meta) === null || _content$meta === void 0 ? void 0 : _content$meta.breakpoints) || {});
    const contentHasXSmallBreakpoint = Boolean(content === null || content === void 0 || (_content$meta2 = content.meta) === null || _content$meta2 === void 0 || (_content$meta2 = _content$meta2.breakpoints) === null || _content$meta2 === void 0 ? void 0 : _content$meta2.xsmall);
    const largeStyles = styles === null || styles === void 0 ? void 0 : styles.large;
    const mediumStyles = styles === null || styles === void 0 ? void 0 : styles.medium;
    const smallStyles = styles === null || styles === void 0 ? void 0 : styles.small;
    const xsmallStyles = styles === null || styles === void 0 ? void 0 : styles.xsmall;
    const className = processedBlock.id;
    if (!className) {
      return "";
    }
    const largeStylesClass = largeStyles ? (0, _css.createCssClass)({
      className,
      styles: largeStyles
    }) : "";
    const mediumStylesClass = mediumStyles ? (0, _css.createCssClass)({
      className,
      styles: mediumStyles,
      mediaQuery: (0, _deviceSizes.getMaxWidthQueryForSize)("medium", sizesWithUpdatedBreakpoints)
    }) : "";
    const smallStylesClass = smallStyles ? (0, _css.createCssClass)({
      className,
      styles: smallStyles,
      mediaQuery: (0, _deviceSizes.getMaxWidthQueryForSize)("small", sizesWithUpdatedBreakpoints)
    }) : "";
    const xsmallStylesClass = xsmallStyles && contentHasXSmallBreakpoint ? (0, _css.createCssClass)({
      className,
      styles: xsmallStyles,
      mediaQuery: (0, _deviceSizes.getMaxWidthQueryForSize)("xsmall", sizesWithUpdatedBreakpoints)
    }) : "";
    const hoverAnimation = processedBlock.animations && processedBlock.animations.find(item => item.trigger === "hover");
    let hoverStylesClass = "";
    if (hoverAnimation) {
      var _hoverAnimation$steps;
      const hoverStyles = ((_hoverAnimation$steps = hoverAnimation.steps) === null || _hoverAnimation$steps === void 0 || (_hoverAnimation$steps = _hoverAnimation$steps[1]) === null || _hoverAnimation$steps === void 0 ? void 0 : _hoverAnimation$steps.styles) || {};
      hoverStylesClass = (0, _css.createCssClass)({
        className: `${className}:hover`,
        styles: {
          ...hoverStyles,
          transition: `all ${hoverAnimation.duration}s ${(0, _camelToKebabCase.camelToKebabCase)(hoverAnimation.easing)}`,
          transitionDelay: hoverAnimation.delay ? `${hoverAnimation.delay}s` : "0s"
        }
      }) || "";
    }
    return [largeStylesClass, mediumStylesClass, smallStylesClass, xsmallStylesClass, hoverStylesClass].join(" ");
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, _target.TARGET !== "reactNative" && css() && canShowBlock() ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_inlinedStyles.default, {
    id: "builderio-block",
    styles: css(),
    nonce: props.context.nonce
  })) : null);
}
var _default = exports.default = BlockStyles;
//# sourceMappingURL=block-styles.js.map