"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var React = _react;
var _reactNative = require("react-native");
var _builder = _interopRequireDefault(require("../../../context/builder.context"));
var _index = require("../../../functions/evaluate/index");
var _fastClone = require("../../../functions/fast-clone");
var _index2 = require("../../../functions/get-content/index");
var _isBrowser = require("../../../functions/is-browser");
var _isEditing = require("../../../functions/is-editing");
var _isPreviewing = require("../../../functions/is-previewing");
var _logFetch = require("../../../functions/log-fetch");
var _registerComponent = require("../../../functions/register-component");
var _index3 = require("../../../functions/track/index");
var _interaction = require("../../../functions/track/interaction");
var _canTrack = require("../../../helpers/canTrack");
var _cookie = require("../../../helpers/cookie");
var _subscribeToEditor = require("../../../helpers/subscribe-to-editor");
var _initEditing = require("../../../scripts/init-editing");
var _animator = require("../../block/animator");
var _enableEditor = require("./enable-editor.helpers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function EnableEditor(props) {
  var _props$builderContext13;
  const elementRef = (0, _react.useRef)(null);
  const [hasExecuted, setHasExecuted] = (0, _react.useState)(() => false);
  function mergeNewRootState(newData) {
    const combinedState = {
      ...props.builderContextSignal.rootState,
      ...newData
    };
    if (props.builderContextSignal.rootSetState) {
      var _props$builderContext, _props$builderContext2;
      (_props$builderContext = (_props$builderContext2 = props.builderContextSignal).rootSetState) === null || _props$builderContext === void 0 || _props$builderContext.call(_props$builderContext2, combinedState);
    } else {
      props.setBuilderContextSignal(PREVIOUS_VALUE => ({
        ...PREVIOUS_VALUE,
        rootState: combinedState
      }));
    }
  }
  function mergeNewContent(newContent) {
    var _props$builderContext3, _props$builderContext4, _newContent$meta, _props$builderContext5;
    const newContentValue = {
      ...props.builderContextSignal.content,
      ...newContent,
      data: {
        ...((_props$builderContext3 = props.builderContextSignal.content) === null || _props$builderContext3 === void 0 ? void 0 : _props$builderContext3.data),
        ...(newContent === null || newContent === void 0 ? void 0 : newContent.data)
      },
      meta: {
        ...((_props$builderContext4 = props.builderContextSignal.content) === null || _props$builderContext4 === void 0 ? void 0 : _props$builderContext4.meta),
        ...(newContent === null || newContent === void 0 ? void 0 : newContent.meta),
        breakpoints: (newContent === null || newContent === void 0 || (_newContent$meta = newContent.meta) === null || _newContent$meta === void 0 ? void 0 : _newContent$meta.breakpoints) || ((_props$builderContext5 = props.builderContextSignal.content) === null || _props$builderContext5 === void 0 || (_props$builderContext5 = _props$builderContext5.meta) === null || _props$builderContext5 === void 0 ? void 0 : _props$builderContext5.breakpoints)
      }
    };
    props.setBuilderContextSignal(PREVIOUS_VALUE => ({
      ...PREVIOUS_VALUE,
      content: newContentValue
    }));
  }
  function showContentProps() {
    return props.showContent ? {} : {
      hidden: true,
      "aria-hidden": true
    };
  }
  const [ContentWrapper, setContentWrapper] = (0, _react.useState)(() => props.contentWrapper || _reactNative.ScrollView);
  function processMessage(event) {
    return (0, _subscribeToEditor.createEditorListener)({
      model: props.model,
      trustedHosts: props.trustedHosts,
      callbacks: {
        configureSdk: messageContent => {
          var _props$builderContext6;
          const {
            breakpoints,
            contentId
          } = messageContent;
          if (!contentId || contentId !== ((_props$builderContext6 = props.builderContextSignal.content) === null || _props$builderContext6 === void 0 ? void 0 : _props$builderContext6.id)) {
            return;
          }
          if (breakpoints) {
            mergeNewContent({
              meta: {
                breakpoints
              }
            });
          }
        },
        animation: animation => {
          (0, _animator.triggerAnimation)(animation);
        },
        contentUpdate: newContent => {
          mergeNewContent(newContent);
        },
        stateUpdate: newState => {
          mergeNewRootState(newState);
        }
      }
    })(event);
  }
  const [httpReqsData, setHttpReqsData] = (0, _react.useState)(() => ({}));
  const [httpReqsPending, setHttpReqsPending] = (0, _react.useState)(() => ({}));
  const [clicked, setClicked] = (0, _react.useState)(() => false);
  function onClick(event) {
    if (props.builderContextSignal.content) {
      var _props$builderContext7, _props$builderContext8;
      const variationId = (_props$builderContext7 = props.builderContextSignal.content) === null || _props$builderContext7 === void 0 ? void 0 : _props$builderContext7.testVariationId;
      const contentId = (_props$builderContext8 = props.builderContextSignal.content) === null || _props$builderContext8 === void 0 ? void 0 : _props$builderContext8.id;
      (0, _index3._track)({
        apiHost: props.apiHost,
        type: "click",
        canTrack: (0, _canTrack.getDefaultCanTrack)(props.canTrack),
        contentId,
        apiKey: props.apiKey,
        variationId: variationId !== contentId ? variationId : undefined,
        ...(0, _interaction.getInteractionPropertiesForEvent)(event),
        unique: !clicked
      });
    }
    if (!clicked) {
      setClicked(true);
    }
  }
  function runHttpRequests() {
    var _props$builderContext9;
    const requests = ((_props$builderContext9 = props.builderContextSignal.content) === null || _props$builderContext9 === void 0 || (_props$builderContext9 = _props$builderContext9.data) === null || _props$builderContext9 === void 0 ? void 0 : _props$builderContext9.httpRequests) ?? {};
    Object.entries(requests).forEach(([key, httpRequest]) => {
      if (!httpRequest) return;
      const isCoreRequest = typeof httpRequest === "object" && httpRequest["@type"] === "@builder.io/core:Request";

      // request already in progress
      if (httpReqsPending[key]) return;

      // request already completed, and not in edit mode
      if (httpReqsData[key] && !(0, _isEditing.isEditing)()) return;
      const url = isCoreRequest ? httpRequest.request.url : httpRequest;
      httpReqsPending[key] = true;
      const evaluatedUrl = url.replace(/{{([^}]+)}}/g, (_match, group) => String((0, _index.evaluate)({
        code: group,
        context: props.context || {},
        localState: undefined,
        rootState: props.builderContextSignal.rootState,
        rootSetState: props.builderContextSignal.rootSetState
      })));
      const fetchRequestObj = isCoreRequest ? {
        url: evaluatedUrl,
        method: httpRequest.request.method,
        headers: httpRequest.request.headers,
        body: httpRequest.request.body
      } : {
        url: evaluatedUrl,
        method: "GET"
      };
      (0, _logFetch.logFetch)(JSON.stringify(fetchRequestObj));
      fetch(fetchRequestObj.url, {
        method: fetchRequestObj.method,
        headers: fetchRequestObj.headers,
        body: fetchRequestObj.body
      }).then(response => response.json()).then(json => {
        mergeNewRootState({
          [key]: json
        });
        httpReqsData[key] = true;
      }).catch(err => {
        console.error("error fetching dynamic data", JSON.stringify(httpRequest), err);
      }).finally(() => {
        httpReqsPending[key] = false;
      });
    });
  }
  function emitStateUpdate() {
    if ((0, _isEditing.isEditing)()) {
      window.dispatchEvent(new CustomEvent("builder:component:stateChange", {
        detail: {
          state: (0, _fastClone.fastClone)(props.builderContextSignal.rootState),
          ref: {
            name: props.model
          }
        }
      }));
    }
  }
  function elementRef_onIniteditingbldr(event) {
    window.addEventListener("message", processMessage);
    (0, _initEditing.setupBrowserForEditing)({
      ...(props.locale ? {
        locale: props.locale
      } : {}),
      ...(props.enrich ? {
        enrich: props.enrich
      } : {}),
      ...(props.trustedHosts ? {
        trustedHosts: props.trustedHosts
      } : {}),
      modelName: props.model ?? "",
      apiKey: props.apiKey
    });
    Object.values(props.builderContextSignal.componentInfos).forEach(registeredComponent => {
      var _registeredComponent$;
      if (!((_registeredComponent$ = registeredComponent.models) !== null && _registeredComponent$ !== void 0 && _registeredComponent$.length) || registeredComponent.models.includes(props.model)) {
        var _window$parent;
        const message = (0, _registerComponent.createRegisterComponentMessage)(registeredComponent);
        (_window$parent = window.parent) === null || _window$parent === void 0 || _window$parent.postMessage(message, "*");
      }
    });
    window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
  }
  function elementRef_onInitpreviewingbldr(event) {
    const searchParams = new URL(location.href).searchParams;
    const searchParamPreviewModel = searchParams.get("builder.preview");
    const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
    const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");

    /**
     * Make sure that:
     * - the preview model name is the same as the one we're rendering, since there can be multiple models rendered *  at the same time, e.g. header/page/footer. * - the API key is the same, since we don't want to preview content from other organizations.
     * - if there is content, that the preview ID is the same as that of the one we receive.
     *
     * TO-DO: should we only update the state when there is a change?
     **/
    if (searchParamPreviewModel === "BUILDER_STUDIO" || searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
      var _props$context;
      (0, _index2.fetchOneEntry)({
        model: props.model,
        apiKey: props.apiKey,
        apiVersion: props.builderContextSignal.apiVersion,
        ...(searchParamPreviewModel === "BUILDER_STUDIO" && (_props$context = props.context) !== null && _props$context !== void 0 && _props$context.symbolId ? {
          query: {
            id: props.context.symbolId
          }
        } : {})
      }).then(content => {
        if (content) {
          mergeNewContent(content);
        }
      });
    }
  }
  const hasInitialized = (0, _react.useRef)(false);
  if (!hasInitialized.current) {
    runHttpRequests();
    emitStateUpdate();
    hasInitialized.current = true;
  }
  (0, _react.useEffect)(() => {
    if ((0, _isBrowser.isBrowser)()) {
      var _props$builderContext10, _props$builderContext11;
      if ((0, _isEditing.isEditing)() && !props.isNestedRender) {
        window.addEventListener("message", processMessage);
        (0, _initEditing.setupBrowserForEditing)({
          ...(props.locale ? {
            locale: props.locale
          } : {}),
          ...(props.enrich ? {
            enrich: props.enrich
          } : {}),
          ...(props.trustedHosts ? {
            trustedHosts: props.trustedHosts
          } : {}),
          modelName: props.model ?? "",
          apiKey: props.apiKey
        });
        Object.values(props.builderContextSignal.componentInfos).forEach(registeredComponent => {
          var _registeredComponent$2;
          if (!((_registeredComponent$2 = registeredComponent.models) !== null && _registeredComponent$2 !== void 0 && _registeredComponent$2.length) || registeredComponent.models.includes(props.model)) {
            var _window$parent2;
            const message = (0, _registerComponent.createRegisterComponentMessage)(registeredComponent);
            (_window$parent2 = window.parent) === null || _window$parent2 === void 0 || _window$parent2.postMessage(message, "*");
          }
        });
        window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
      }
      const shouldTrackImpression = props.builderContextSignal.content && (0, _canTrack.getDefaultCanTrack)(props.canTrack);
      const winningVariantId = (0, _cookie.getCookieSync)({
        name: `builder.tests.${(_props$builderContext10 = props.builderContextSignal.content) === null || _props$builderContext10 === void 0 ? void 0 : _props$builderContext10.id}`,
        canTrack: true
      });
      const variationId = (_props$builderContext11 = props.builderContextSignal.content) === null || _props$builderContext11 === void 0 ? void 0 : _props$builderContext11.testVariationId;
      if (shouldTrackImpression && variationId === winningVariantId) {
        var _props$builderContext12;
        const contentId = (_props$builderContext12 = props.builderContextSignal.content) === null || _props$builderContext12 === void 0 ? void 0 : _props$builderContext12.id;
        const apiKeyProp = props.apiKey;
        (0, _index3._track)({
          apiHost: props.apiHost,
          type: "impression",
          canTrack: true,
          contentId,
          apiKey: apiKeyProp,
          variationId: winningVariantId !== contentId ? winningVariantId : undefined
        });
      }

      /**
       * Override normal content in preview mode.
       * We ignore this when editing, since the edited content is already being sent from the editor via post messages.
       */
      if ((0, _isPreviewing.isPreviewing)() && !(0, _isEditing.isEditing)()) {
        const searchParams = new URL(location.href).searchParams;
        const searchParamPreviewModel = searchParams.get("builder.preview");
        const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
        const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");

        /**
         * Make sure that:
         * - the preview model name is the same as the one we're rendering, since there can be multiple models rendered   *  at the same time, e.g. header/page/footer.   * - the API key is the same, since we don't want to preview content from other organizations.
         * - if there is content, that the preview ID is the same as that of the one we receive.
         *
         * TO-DO: should we only update the state when there is a change?
         **/
        if (searchParamPreviewModel === "BUILDER_STUDIO" || searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
          var _props$context2;
          (0, _index2.fetchOneEntry)({
            model: props.model,
            apiKey: props.apiKey,
            apiVersion: props.builderContextSignal.apiVersion,
            ...(searchParamPreviewModel === "BUILDER_STUDIO" && (_props$context2 = props.context) !== null && _props$context2 !== void 0 && _props$context2.symbolId ? {
              query: {
                id: props.context.symbolId
              }
            } : {})
          }).then(content => {
            if (content) {
              mergeNewContent(content);
            }
          });
        }
      }
    }
  }, []);
  (0, _react.useEffect)(() => {
    if (props.content) {
      mergeNewContent(props.content);
    }
  }, [props.content]);
  (0, _react.useEffect)(() => {
    emitStateUpdate();
  }, [props.builderContextSignal.rootState]);
  (0, _react.useEffect)(() => {
    if (props.data) {
      mergeNewRootState(props.data);
    }
  }, [props.data]);
  (0, _react.useEffect)(() => {
    if (props.locale) {
      mergeNewRootState({
        locale: props.locale
      });
    }
  }, [props.locale]);
  (0, _react.useEffect)(() => {
    return () => {
      if ((0, _isBrowser.isBrowser)()) {
        window.removeEventListener("message", processMessage);
        window.removeEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
      }
    };
  }, []);
  return /*#__PURE__*/React.createElement(_builder.default.Provider, {
    value: props.builderContextSignal
  }, props.builderContextSignal.content || (0, _enableEditor.needsElementRefDivForEditing)() ? /*#__PURE__*/React.createElement(ContentWrapper, _extends({
    ref: elementRef,
    onClick: event => onClick(event),
    "builder-content-id": (_props$builderContext13 = props.builderContextSignal.content) === null || _props$builderContext13 === void 0 ? void 0 : _props$builderContext13.id,
    "builder-model": props.model,
    style: {
      display: !props.builderContextSignal.content && (0, _enableEditor.needsElementRefDivForEditing)() ? "none" : undefined
    },
    // currently, we can't set the actual ID here. // we don't need it right now, we just need to identify content divs for testing.
    dataSet: {
      "builder-content-id": ""
    }
  }, showContentProps(), props.contentWrapperProps), props.children) : null);
}
var _default = exports.default = EnableEditor;
//# sourceMappingURL=enable-editor.js.map