"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializeNodeRuntime = void 0;
var _shouldForceBrowserRuntimeInNode = require("../should-force-browser-runtime-in-node");
var _isolatedVm = _interopRequireDefault(require("isolated-vm"));
var _nodeRuntime = require("./node-runtime");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * This file:
 * - imports `isolated-vm`, which can only be made from a file that never runs
 * on the client (e.g. Next's `_document.tsx`)
 * - stores the ivm instance in a global variable using `setIvm`
 *
 * This is needed for when bundlers/meta-frameworks are not able to reliably
 * import the `isolated-vm` package using our `safeDynamicRequire` trick.
 *
 * The `isolated-vm` import must exist in this separate file, or it will end up
 * in the SDK's main entry point, causing errors for users.
 */

/**
 * This function initializes the SDK on a Node server. It handles importing the
 * `isolated-vm` package which is needed for dynamic bindings.
 *
 * NOTE: this function cannot be called on the client. You must call this function
 * from a server-only location, such as:
 * - The NextJS Pages router's `_document.tsx`
 * - Your Remix route's `loader`
 * - Qwik's `entry.ssr.tsx` file
 */
const initializeNodeRuntime = args => {
  /**
   * skip initialization if we are on an arm64 machine and running node 20
   */
  if ((0, _shouldForceBrowserRuntimeInNode.shouldForceBrowserRuntimeInNode)({
    shouldLogWarning: true
  })) {
    return;
  }
  const {
    ivmIsolateOptions
  } = args || {};
  (0, _nodeRuntime.setIvm)(_isolatedVm.default, ivmIsolateOptions);
};
exports.initializeNodeRuntime = initializeNodeRuntime;
//# sourceMappingURL=init.js.map