"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRegisterComponentMessage = void 0;
exports.serializeIncludingFunctions = serializeIncludingFunctions;
const createRegisterComponentMessage = info => ({
  type: 'builder.registerComponent',
  data: serializeIncludingFunctions(info)
});

// eslint-disable-next-line @typescript-eslint/ban-types
exports.createRegisterComponentMessage = createRegisterComponentMessage;
const serializeFn = fnValue => {
  const fnStr = fnValue.toString().trim();

  // we need to account for a few different fn syntaxes:
  // 1. `function name(args) => {code}`
  // 2. `name(args) => {code}`
  // 3. `(args) => {}`
  // 4. `args => {}`
  // 5. `async function(args) {code}`
  // 6. `async (args) => {}`
  // 7. `async args => {}`
  const isArrowWithoutParens = /^[a-zA-Z0-9_]+\s*=>/i.test(fnStr);
  const appendFunction = !fnStr.startsWith('function') && !fnStr.startsWith('async') && !fnStr.startsWith('(') && !isArrowWithoutParens;
  return `return (${appendFunction ? 'function ' : ''}${fnStr}).apply(this, arguments)`;
};
function serializeIncludingFunctions(info) {
  return JSON.parse(JSON.stringify(info, (key, value) => {
    if (typeof value === 'function') {
      return serializeFn(value);
    }
    return value;
  }));
}
//# sourceMappingURL=register-component.js.map