"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setVisitorId = exports.getVisitorId = exports.createVisitorId = void 0;
var _localStorage = require("./localStorage");
var _nullable = require("./nullable");
var _uuid = require("./uuid");
const VISITOR_LOCAL_STORAGE_KEY = 'builderVisitorId';
const getVisitorId = ({
  canTrack
}) => {
  if (!canTrack) {
    return undefined;
  }
  const visitorId = (0, _localStorage.getLocalStorageItem)({
    key: VISITOR_LOCAL_STORAGE_KEY,
    canTrack
  });
  if ((0, _nullable.checkIsDefined)(visitorId)) {
    return visitorId;
  } else {
    const newVisitorId = createVisitorId();
    setVisitorId({
      id: newVisitorId,
      canTrack
    });
    return newVisitorId;
  }
};
exports.getVisitorId = getVisitorId;
const createVisitorId = () => (0, _uuid.uuid)();
exports.createVisitorId = createVisitorId;
const setVisitorId = ({
  id,
  canTrack
}) => (0, _localStorage.setLocalStorageItem)({
  key: VISITOR_LOCAL_STORAGE_KEY,
  value: id,
  canTrack
});
exports.setVisitorId = setVisitorId;
//# sourceMappingURL=visitorId.js.map