import BaseText from "../../blocks/BaseText";
import * as React from "react";
import { View } from "react-native";
import { useState, useEffect } from "react";
import { TARGET } from "../../constants/target";
import { getBlockComponentOptions } from "../../functions/get-block-component-options";
import { getProcessedBlock } from "../../functions/get-processed-block";
import { isPreviewing } from "../../server-index";
import { generateKey, getComponent, getInheritedStyles, getRepeatItemData, provideBuilderBlock, provideBuilderContext, provideLinkComponent, provideRegisteredComponents } from "./block.helpers";
import BlockStyles from "./components/block-styles";
import BlockWrapper from "./components/block-wrapper";
import ComponentRef from "./components/component-ref/component-ref";
import RepeatedBlock from "./components/repeated-block";
import { memo } from "react";
function Block(props) {
  var _blockComponent5, _childrenWithoutParen, _repeatItem2, _repeatItem3;
  function repeatItem() {
    return getRepeatItemData({
      block: props.block,
      context: props.context
    });
  }
  const [_processedBlock, set_processedBlock] = useState(() => ({
    value: null,
    update: false
  }));
  function processedBlock() {
    var _props$block$repeat;
    if (_processedBlock.value && !_processedBlock.update && !isPreviewing()) {
      return _processedBlock.value;
    }
    const blockToUse = (_props$block$repeat = props.block.repeat) !== null && _props$block$repeat !== void 0 && _props$block$repeat.collection ? props.block : getProcessedBlock({
      block: props.block,
      localState: props.context.localState,
      rootState: props.context.rootState,
      rootSetState: props.context.rootSetState,
      context: props.context.context
    });
    _processedBlock.value = blockToUse;
    _processedBlock.update = false;
    return blockToUse;
  }
  function blockComponent() {
    return getComponent({
      block: processedBlock(),
      registeredComponents: props.registeredComponents,
      model: props.context.model
    });
  }
  function Tag() {
    var _processedBlock$prope;
    const shouldUseLink = props.block.tagName === "a" || ((_processedBlock$prope = processedBlock().properties) === null || _processedBlock$prope === void 0 ? void 0 : _processedBlock$prope.href) || processedBlock().href;
    if (shouldUseLink) {
      return props.linkComponent || BaseText;
    }
    return View;
  }
  function canShowBlock() {
    var _props$block$repeat2;
    if ((_props$block$repeat2 = props.block.repeat) !== null && _props$block$repeat2 !== void 0 && _props$block$repeat2.collection) {
      var _repeatItem;
      if (repeatItem !== null && repeatItem !== void 0 && (_repeatItem = repeatItem()) !== null && _repeatItem !== void 0 && _repeatItem.length) return true;
      return false;
    }
    const shouldHide = "hide" in processedBlock() ? processedBlock().hide : false;
    const shouldShow = "show" in processedBlock() ? processedBlock().show : true;
    return shouldShow && !shouldHide;
  }
  function childrenWithoutParentComponent() {
    var _blockComponent;
    /**
     * When there is no `componentRef`, there might still be children that need to be rendered. In this case,
     * we render them outside of `componentRef`.
     * NOTE: We make sure not to render this if `repeatItemData` is non-null, because that means we are rendering an array of
     * blocks, and the children will be repeated within those blocks.
     */
    const shouldRenderChildrenOutsideRef = !(blockComponent !== null && blockComponent !== void 0 && (_blockComponent = blockComponent()) !== null && _blockComponent !== void 0 && _blockComponent.component) && !repeatItem();
    return shouldRenderChildrenOutsideRef ? processedBlock().children ?? [] : [];
  }
  function componentRefProps() {
    var _blockComponent2, _blockComponent3, _blockComponent4;
    return {
      blockChildren: processedBlock().children ?? [],
      componentRef: blockComponent === null || blockComponent === void 0 || (_blockComponent2 = blockComponent()) === null || _blockComponent2 === void 0 ? void 0 : _blockComponent2.component,
      componentOptions: {
        ...getBlockComponentOptions(processedBlock(), props.context),
        ...provideBuilderBlock(blockComponent(), processedBlock()),
        ...provideBuilderContext(blockComponent(), props.context),
        ...provideLinkComponent(blockComponent(), props.linkComponent),
        ...provideRegisteredComponents(blockComponent(), props.registeredComponents, props.context.model)
      },
      context: {
        ...props.context,
        inheritedStyles: getInheritedStyles({
          block: processedBlock(),
          context: props.context
        })
      },
      linkComponent: props.linkComponent,
      registeredComponents: props.registeredComponents,
      builderBlock: processedBlock(),
      includeBlockProps: (blockComponent === null || blockComponent === void 0 || (_blockComponent3 = blockComponent()) === null || _blockComponent3 === void 0 ? void 0 : _blockComponent3.noWrap) === true,
      isInteractive: !(blockComponent !== null && blockComponent !== void 0 && (_blockComponent4 = blockComponent()) !== null && _blockComponent4 !== void 0 && _blockComponent4.isRSC && TARGET === "rsc")
    };
  }
  useEffect(() => {}, []);
  useEffect(() => {
    _processedBlock.update = true;
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, canShowBlock() ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(BlockStyles, {
    block: processedBlock(),
    context: props.context
  }), !(blockComponent !== null && blockComponent !== void 0 && (_blockComponent5 = blockComponent()) !== null && _blockComponent5 !== void 0 && _blockComponent5.noWrap) ? /*#__PURE__*/React.createElement(React.Fragment, null, !repeatItem() ? /*#__PURE__*/React.createElement(BlockWrapper, {
    Wrapper: Tag(),
    block: processedBlock(),
    context: props.context
  }, /*#__PURE__*/React.createElement(ComponentRef, {
    componentRef: componentRefProps().componentRef,
    componentOptions: componentRefProps().componentOptions,
    blockChildren: componentRefProps().blockChildren,
    context: componentRefProps().context,
    registeredComponents: componentRefProps().registeredComponents,
    linkComponent: componentRefProps().linkComponent,
    builderBlock: componentRefProps().builderBlock,
    includeBlockProps: componentRefProps().includeBlockProps,
    isInteractive: componentRefProps().isInteractive
  }), (_childrenWithoutParen = childrenWithoutParentComponent()) === null || _childrenWithoutParen === void 0 ? void 0 : _childrenWithoutParen.map(child => /*#__PURE__*/React.createElement(Block, {
    key: child.id,
    block: child,
    registeredComponents: props.registeredComponents,
    linkComponent: props.linkComponent,
    context: {
      ...props.context,
      inheritedStyles: getInheritedStyles({
        block: processedBlock(),
        context: props.context
      })
    }
  }))) : /*#__PURE__*/React.createElement(React.Fragment, null, (_repeatItem2 = repeatItem()) === null || _repeatItem2 === void 0 ? void 0 : _repeatItem2.map((data, index) => /*#__PURE__*/React.createElement(RepeatedBlock, {
    key: generateKey(index),
    repeatContext: data.context,
    block: data.block,
    registeredComponents: props.registeredComponents,
    linkComponent: props.linkComponent
  })))) : !repeatItem() ? /*#__PURE__*/React.createElement(ComponentRef, {
    componentRef: componentRefProps().componentRef,
    componentOptions: componentRefProps().componentOptions,
    blockChildren: componentRefProps().blockChildren,
    context: componentRefProps().context,
    registeredComponents: componentRefProps().registeredComponents,
    linkComponent: componentRefProps().linkComponent,
    builderBlock: componentRefProps().builderBlock,
    includeBlockProps: componentRefProps().includeBlockProps,
    isInteractive: componentRefProps().isInteractive
  }) : /*#__PURE__*/React.createElement(React.Fragment, null, (_repeatItem3 = repeatItem()) === null || _repeatItem3 === void 0 ? void 0 : _repeatItem3.map((data, index) => /*#__PURE__*/React.createElement(RepeatedBlock, {
    key: generateKey(index),
    repeatContext: data.context,
    block: data.block,
    registeredComponents: props.registeredComponents,
    linkComponent: props.linkComponent
  })))) : null);
}
export default /*#__PURE__*/memo(Block);
//# sourceMappingURL=block.js.map